load Pt2Data_real

%% plot optimal outputs
for iPhase = 1:nPhases
    % get computed output values
    y_opt{iPhase} = phase(iPhase).Model.ModelOutputGrid.Values;
    
    % plot output data
    hFig(iPhase) = figure();
    hAxes(2*iPhase-1) = subplot(2,1,1);
    hold on
    hPlot(2*iPhase-1, 1) = plot(t_data{iPhase}, z_data{iPhase}(1,:));
    hPlot(2*iPhase-1, 2) = plot(t_data{iPhase}, y_data{iPhase}(1,:));
    hPlot(2*iPhase-1, 3) = plot(t_data{iPhase}, y_opt{iPhase}(1,:));
    hYLabel(2*iPhase-1) = ylabel('y_1');
    
    hAxes(2*iPhase) = subplot(2,1,2);
    hold on
    hPlot(2*iPhase, 1) = plot(t_data{iPhase}, z_data{iPhase}(2,:));
    hPlot(2*iPhase, 2) = plot(t_data{iPhase}, y_data{iPhase}(2,:));
    hPlot(2*iPhase, 3) = plot(t_data{iPhase}, y_opt{iPhase}(2,:));
    hYLabel(2*iPhase) = ylabel('y_2');
    hXLabel(iPhase) = xlabel('t [s]');
    
    hLegend = legend('measurements', 'original system behaviour', 'reconstructed trajectory', ...
        'Location', 'southeast');
end
linkaxes(hAxes(1:2:end), 'y')
linkaxes(hAxes(2:2:end), 'y')

%% Display Information w.r.t. parameters
fprintf('\n### RESULTS ###\n');
fprintf('d_opt       = %0.4f\t(%0.2g)\n',p(1).Value, d_real);
fprintf('omega_0_opt = %0.4f\t(%0.4g)\n',p(2).Value, omega_0_real);
fprintf('k_s_opt     = %0.4f\t(%0.4g)\n',p(3).Value, k_s_real);

%% format plots
set(hPlot(:, 1),...
    'LineStyle',         'none',...
    'Marker',            'o',...
    'MarkerSize',        3,...
    'MarkerEdgeColor' ,  [0.1 0.1 0.4]      , ...
    'MarkerFaceColor' ,  [0.85 0.85 1],...
    'Color',             [0 0 1],...
    'visible',           'on');

set(hPlot(:, 2),...
    'LineStyle',         '-',...
    'LineWidth',         3,...
    'Marker',            'none',...
    'MarkerSize',        3,...
    'MarkerEdgeColor' ,  [0.1 0.1 0.4]      , ...
    'MarkerFaceColor' ,  [0.1 0.7 1],...
    'Color',             [0.25 0.4 1],...
    'visible',           'on');

set(hPlot(:, 3),...
    'LineStyle',         '-.',...
    'LineWidth',         3,...
    'Marker',            'none',...
    'MarkerSize',        3,...
    'MarkerEdgeColor' ,  [0.1 0.1 0.4]      , ...
    'MarkerFaceColor' ,  [0.1 0.7 1],...
    'Color',             [1 0 0],...
    'visible',           'on');

% Fonts and Ticks

set([hYLabel, hXLabel], ...
    'FontSize'   , 11, ...
    'fontweight','bold',...
    'Interpreter','Tex', ...
    'FontName'   , 'AvantGarde');

set( hAxes                     , ...
    'FontName'   , 'Helvetica' );

set([hLegend, hAxes]             , ...
    'FontSize'   , 11           );

set(hAxes, ...
    'Box'         , 'off',...
    'TickDir'     , 'out',...
    'TickLength'  , [.01 .01],...
    'XMinorTick'  , 'on',...
    'YMinorTick'  , 'on',...
    'XMinorGrid'       , 'off',...
    'YMinorGrid'       , 'on',...
    'XGrid'       , 'off',...
    'YGrid'       , 'on',...
    'MinorGridLineStyle',':',...
    'GridLineStyle' ,'-',...
    'MinorGridAlpha', .2,...
    'GridAlpha'     , .1,...
    'XColor'      , [.3 .3 .3], ...
    'YColor'      , [.3 .3 .3],...
    'XTick'       , 0:1:50,...
    'YTick'       , -10:2:10,...
    'LineWidth'   , 1      );

% Window size
set(hFig, 'Position', [10 50 800 500]);
